@@ -1,10 +1,8 @@
-import path from 'node:path';
-import process from 'node:process';
-import {fileURLToPath} from 'node:url';
 import test from 'ava';
 import {execa} from '../index.js';
+import {setFixtureDir} from './helpers/fixtures-dir.js';
 
-process.env.PATH = fileURLToPath(new URL('fixtures', import.meta.url)) + path.delimiter + process.env.PATH;
+setFixtureDir();
 
 test('promise methods are not enumerable', t => {
 	const descriptors = Object.getOwnPropertyDescriptors(execa('noop.js'));
